pub fn load_config(path: &Path) -> Result<ProjectConfig>Expand description
Load and validate a ProjectConfig from a TOML file.
If path does not exist and is the default oxigaf.toml, returns the
default configuration instead of erroring.
pub fn load_config(path: &Path) -> Result<ProjectConfig>Load and validate a ProjectConfig from a TOML file.
If path does not exist and is the default oxigaf.toml, returns the
default configuration instead of erroring.